package Facebook::Graph::Query::Response;
BEGIN {
  $Facebook::Graph::Query::Response::VERSION = '0.0201';
}

use Moose;
use JSON;

has response => (
    is      => 'ro',
    required=> 1,
);

has as_json => (
    is      => 'ro',
    lazy    => 1,
    default => sub {
        my $self = shift;
        my $response = $self->response;
        if ($response->is_success) {
            return $response->content;
        }
        else {
            my $message = $response->message;
            my $error = eval { JSON->new->decode($response->content) };
            unless ($@) {
                $message = $error->{error}{type} . ' - ' . $error->{error}{message};
            }
            confess [$response->code, 'Could not execute query ('.$response->request->uri->as_string.'): '.$message];
        }
    },
);

has as_hashref => (
    is      => 'ro',
    lazy    => 1,
    default => sub {
        my $self = shift;
        return JSON->new->decode($self->as_json);
    },
);

no Moose;
__PACKAGE__->meta->make_immutable;

=head1 NAME

Facebook::Graph::Query::Response - Handling of a Facebook::Graph::Query result set.

=head1 VERSION

version 0.0201

=head1 DESCRIPTION

You'll be given one of these as a result of calling the C<request> method on a C<Facebook::Graph::Query> object.


=head1 METHODS

=head2 as_json ()

Returns the response from Facebook as a JSON string.

=head2 as_hashref ()

Returns the response from Facebook as a hash reference.

=head2 response ()

Direct access to the L<HTTP::Response> object.

=head1 LEGAL

Facebook::Graph is Copyright 2010 Plain Black Corporation (L<http://www.plainblack.com>) and is licensed under the same terms as Perl itself.

=cut